@@ -323,10 +323,16 @@ class EmsLayer(object):
             logger.info("All the features were deleted successfully.")
         return response_dict
 
-    def attachments(self, feature_id="1"):
-        """Get all the attachments for a layer
+    def attachments(self, feature_id="1", asUrl=False, appType="master"):
+        """
+        This will list all the attachment infos for given feature.
 
-        not officially supported yet
+        Args:
+
+            feature_id (int): The id of the feature
+            asUrl (bool): Return the storage path of the attachment. Using this
+                          option is a security risk!
+            appType (str): archive/preview/maste(default)
         """
 
         url = "/".join(
@@ -339,29 +345,11 @@ class EmsLayer(object):
                 "attachments",
             ]
         )
-        get_params = {
-            "f": "json",
-        }
+        get_params = {"f": "json", "asUrl": asUrl, "appType": appType}
         response = self._session.get(url, params=get_params)
         response_dict = response.json()
 
-        # updateResults could have more than one result sets
-        try:
-            for i in range(len(response_dict["attachmentsInfo"])):
-                attchment_info = response_dict["attachmentsInfo"][i]
-                logger.info(
-                    "%s.%s type: %s - size %s",
-                    attchment_info["name"],
-                    attchment_info["extension"],
-                    attchment_info["contentType"],
-                    attchment_info["size"],
-                )
-        except KeyError:
-            error_dictionary = response_dict["error"]
-            logger.error("Message: %s", error_dictionary["message"])
-            logger.error("Description: %s", error_dictionary["description"])
-            logger.error("Code: %s", error_dictionary["code"])
-            return None
+        logger.debug(response_dict)
 
         logger.info("Successfully queried the attachments.")
         return response_dict
